<?php
/**
* @package		Joomla
* @Copyright ((c) bigemot.ru
* @license    GNU/GPL
*/
defined('_JEXEC') or die;

class PayperfileModelStatistics extends JModelList
{
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'a.id',
				'date', 'a.date',
				'ps', 'a.ps',
				'ip', 'a.ip',
				'fileid', 'a.fileid',
				'state', 'a.state',
				'fm', 'a.fm',
				'amount', 'a.amount',
				'currency', 'a.currency',
				'user', 'a.user',
			);
		}

		parent::__construct($config);
	}
	
	protected function populateState($ordering = null, $direction = null)
	{
		$app = JFactory::getApplication('administrator');

		$fm = $this->getUserStateFromRequest($this->context.'.filter.fm', 'filter_fm', '');
		$this->setState('filter.fm', $fm);

		$ps = $this->getUserStateFromRequest($this->context.'.filter.ps', 'filter_ps', '');
		$this->setState('filter.ps', $ps);

		$categoryId = $this->getUserStateFromRequest($this->context.'.filter.catid', 'filter_catid', '');
		$this->setState('filter.catid', $categoryId);

		$accessId = $this->getUserStateFromRequest($this->context.'.filter.access', 'filter_access', null, 'int');
		$this->setState('filter.access', $accessId);

		$language = $this->getUserStateFromRequest($this->context.'.filter.language', 'filter_language', '', 'string');
		$this->setState('filter.language', $language);

		$published = $this->getUserStateFromRequest($this->context.'.filter.state', 'filter_state', '', 'string');
		$this->setState('filter.state', $published);

		$search = $this->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$min = $this->getUserStateFromRequest($this->context.'.filter.min', 'filter_min');
		$this->setState('filter.min', $min);

		$max = $this->getUserStateFromRequest($this->context.'.filter.max', 'filter_max');
		$this->setState('filter.max', $max);

		$params = JComponentHelper::getParams('com_payperfile');
		$this->setState('params', $params);

		parent::populateState('a.id', 'asc');
	}
	
	protected function getStoreId($id = '')
	{
		$id.= ':' . $this->getState('filter.search');
		$id.= ':' . $this->getState('filter.access');
		$id.= ':' . $this->getState('filter.state');
		$id.= ':' . $this->getState('filter.fm');
		$id.= ':' . $this->getState('filter.catid');
		$id.= ':' . $this->getState('filter.ps');
		$id.= ':' . $this->getState('filter.language');
		$id.= ':' . $this->getState('filter.min');
		$id.= ':' . $this->getState('filter.max');

		return parent::getStoreId($id);
	}
	
	protected function getListQuery()
	{
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);
		$user	= JFactory::getUser();
		$app	= JFactory::getApplication();

		$query->select(
			$this->getState('list.select',	'a.*')
		);
		
		$query->from($db->quoteName('#__payperfile_stat').' AS a');

		$query->select('p.title');
		$query->join('LEFT', $db->quoteName('#__payperfile').' AS p ON p.id = a.fileid');

		$query->select('ua.username');
		$query->join('LEFT', '#__users AS ua ON ua.id = a.user');

		$query->select('c.title AS category_title');
		$query->join('LEFT', '#__categories AS c ON c.id = p.catid');

		if ($fm = $this->getState('filter.fm')) {
			$query->where('a.fm = ' . $db->quote($fm));
		}

		if ($ps = $this->getState('filter.ps')) {
			$query->where('a.ps = ' . $db->quote($ps));
		}

		$categoryId = $this->getState('filter.catid');
		if (is_numeric($categoryId)) {
			$query->where('p.catid = '.(int) $categoryId);
		}

		$published = $this->getState('filter.state');
		if (is_numeric($published)) {
			$query->where('a.state = '.(int) $published);
		} elseif ($published === '') {
			$query->where('(a.state IN (0, 1))');
		}

		if ($access = $this->getState('filter.access')) {
			$query->where('p.access = '.(int) $access);
		}

		if (!$user->authorise('core.admin')){
			$groups	= implode(',', $user->getAuthorisedViewLevels());
			$query->where('p.access IN ('.$groups.')');
		}

		if ($language = $this->getState('filter.language')) {
			$query->where('p.language = ' . $db->quote($language));
		}

		if ($fileid = JRequest::getInt( 'fileid', NULL )) {
			$query->where('a.fileid = ' .(int)$fileid);
		}

		if ($min = $this->getState('filter.min')) {
			if(!empty($min))$query->where('a.date > ' . strtotime($min));
		}
		if ($max = $this->getState('filter.max')) {
			if(!empty($max))$query->where('a.date < ' . strtotime($max));
		}

		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where('(a.email LIKE '.$search.' OR a.params LIKE '.$search.')');
			}
		}

		$orderCol	= $this->state->get('list.ordering');
		$orderDirn	= $this->state->get('list.direction');
		
		$query->order($db->escape($orderCol.' '.$orderDirn));

		return $query;
	}

}
